@@ -1,4 +1,3 @@
-#!/usr/bin/env python3
 #
 # Copyright (c) 2017-present, Facebook, Inc.
 # All rights reserved.
@@ -11,7 +10,8 @@ import re
 from contextlib import contextmanager
 
 from lxml import etree
-from pystemd.dbuslib import apply_signature, DBus
+
+from pystemd.dbuslib import DBus, apply_signature
 from pystemd.utils import x2char_star
 
 
