@@ -1,4 +1,3 @@
-#!/usr/bin/env python3
 #
 # Copyright (c) 2017-present, Facebook, Inc.
 # All rights reserved.
@@ -7,7 +6,7 @@
 # the root directory of this source tree.
 #
 
-from pystemd.base import overwrite_interface_method, SDObject
+from pystemd.base import SDObject, overwrite_interface_method
 from pystemd.dbuslib import apply_signature
 from pystemd.systemd1.unit_signatures import signature_array
 
