@@ -1,4 +1,3 @@
-#!/usr/bin/env python3
 #
 # Copyright (c) 2017-present, Facebook, Inc.
 # All rights reserved.
@@ -11,7 +10,6 @@
 from pystemd.dbuslib import apply_signature
 from pystemd.utils import x2char_star
 
-
 # This is where we add the units and signatures, we steal most of this from
 # https://github.com/systemd/systemd/tree/master/src/core/ any of the dbus-*.c
 # has that data.
@@ -165,7 +163,6 @@ KNOWN_UNIT_SIGNATURES = {
     b"RuntimeDirectory": b"as",
     b"RuntimeDirectoryPreserve": b"s",
     b"ConfigurationDirectory": b"as",
-    b"JoinsNamespaceOf": b"as",
     b"PrivateDevices": b"b",
     b"PrivateIPC": b"b",
     b"PrivateMounts": b"b",
@@ -185,6 +182,9 @@ KNOWN_UNIT_SIGNATURES = {
     b"RestartPreventExitStatus": b"(aiai)",
     b"RestartForceExitStatus": b"(aiai)",
     b"SuccessExitStatus": b"(aiai)",
+    b"Restart": b"s",
+    b"RestartUSec": b"t",
+    b"RestartSec": lambda _, value: (b"RestartUSec", b"t", int(value * 10**6)),
     # Limits
     b"LimitCPU": b"t",
     b"LimitCPUSoft": b"t",
@@ -321,6 +321,55 @@ KNOWN_UNIT_SIGNATURES = {
     b"TriggerLimitBurst": b"u",
     b"UID": b"u",
     b"GID": b"u",
+    b"Id": b"s",
+    b"Names": b"as",
+    b"Following": b"s",
+    b"Upholds": b"as",
+    b"UpheldBy": b"as",
+    b"OnSuccess": b"as",
+    b"OnSuccessOf": b"as",
+    b"OnFailureOf": b"as",
+    b"PropagatesStopTo": b"as",
+    b"StopPropagatedFrom": b"as",
+    b"SliceOf": b"as",
+    b"AccessSELinuxContext": b"s",
+    b"LoadState": b"s",
+    b"ActiveState": b"s",
+    b"FreezerState": b"s",
+    b"SubState": b"s",
+    b"FragmentPath": b"s",
+    b"DropInPaths": b"as",
+    b"UnitFileState": b"s",
+    b"UnitFilePreset": b"s",
+    b"CanStart": b"b",
+    b"CanStop": b"b",
+    b"CanReload": b"b",
+    b"CanIsolate": b"b",
+    b"CanClean": b"as",
+    b"CanFreeze": b"b",
+    b"OnSuccesJobMode": b"s",
+    b"OnSuccessJobMode": b"s",
+    b"NeedDaemonReload": b"b",
+    b"Markers": b"as",
+    b"JobTimeoutUSec": b"t",
+    b"JobRunningTimeoutUSec": b"t",
+    b"ConditionResult": b"b",
+    b"AssertResult": b"b",
+    b"Transient": b"b",
+    b"Perpetual": b"b",
+    b"StartLimitIntervalUSec": b"t",
+    b"StartLimitBurst": b"u",
+    b"StartLimitAction": b"s",
+    b"FailureActionExitStatus": b"i",
+    b"SuccessActionExitStatus": b"i",
+    b"InvocationID": b"ay",
+    b"Refs": b"as",
+    b"RequiresOverridable": b"as",
+    b"RequisiteOverridable": b"as",
+    b"RequiredByOverridable": b"as",
+    b"RequisiteOfOverridable": b"as",
+    b"StartLimitInterval": b"t",
+    b"StartLimitIntervalSec": b"t",
     # Extra
     b"_custom": lambda _, value: value,
 }
